# AnnoRead

Annoread is a utility to annotation the read fot the gene it belong to.

## Requirements

- biobrary

## installation

`pip install annoread`

## Usage

### annoread:

Annotated the reads based on mapping data, GTF file and transcriptomic FASTA file.

### assignread

Assign reads which mapped to multiple features.

### countmtx

Count the read number of features in different levels.
